#!/bin/bash

download_repo() {
  REPO_DIR=$1
  REPO_URL=$2
  echo "Downloading $REPO_DIR"
  if [ -d "$REPO_DIR" ]; then
    (cd "$REPO_DIR" && git pull)
  else
    git clone "$REPO_URL" "$REPO_DIR"
  fi
}

# download_repo chnroutes2 https://github.com/misakaio/chnroutes2.git
download_repo dnsmasq-china-list https://github.com/felixonmars/dnsmasq-china-list.git
download_repo mycard-dnsmasq https://code.mycard.moe/mycard/dnsmasq

cd dnsmasq-china-list
make smartdns
cd ..

rm -rf ./data/china-list.conf
sed 's/114.114.114.114/china/g' ./dnsmasq-china-list/*.smartdns.conf >> ./data/china-list.conf
grep -P '^bogus-nxdomain=.+$' dnsmasq-china-list/bogus-nxdomain.china.conf | sed 's/=/ /g' >> ./data/china-list.conf

# cd lists
# python3 route_helper.py
# cd ..

curl -sL https://cokebar.github.io/gfwlist2dnsmasq/dnsmasq_gfwlist_ipset.conf | grep -P '^ipset=' > ./data/gfwlist-ipset.conf

MENU_VERSION=$(curl -sL "https://api.github.com/repos/netbootxyz/netboot.xyz/releases/latest" | jq -r '.tag_name')
echo "Netboot version: ${MENU_VERSION}"
cd data
wget -m http://boot.netboot.xyz
wget -O boot.netboot.xyz/memdisk http://boot.netboot.xyz/memdisk
wget -O boot.netboot.xyz/wimboot http://boot.netboot.xyz/wimboot
mkdir pxe-menus
wget -O - https://github.com/netbootxyz/netboot.xyz/releases/download/${MENU_VERSION}/menus.tar.gz | tar zxf - -C ./pxe-menus/
rm -rf pxe-menus/boot.cfg
cp -rf boot.netboot.xyz/ipxe/netboot.xyz* ./pxe-menus/

# custom pxes
cp -rf ../files/pxe/centos.ipxe ./pxe-menus/
cp -rf ../files/pxe/ubuntu.ipxe ./pxe-menus/
cp -rf ../files/pxe/menu.ipxe ./pxe-menus/
cp -rf ../files/pxe/menu.ipxe boot.netboot.xyz/
cp -rf pxe-menus/version.ipxe boot.netboot.xyz/
# cp -rf ../files/pxe/nbxyz.ipxe ./pxe-menus/

# ubuntu-squash
_download_ubuntu_squash() {
  GITHUB_RELEASE_VERSION=$1
  DIR_PREFIX="boot.netboot.xyz/ubuntu-squash/$GITHUB_RELEASE_VERSION"
  echo "Downloading ubuntu-squash of $GITHUB_RELEASE_VERSION"
  mkdir -p "$DIR_PREFIX"
  wget -O "$DIR_PREFIX/initrd" "https://github.com/netbootxyz/ubuntu-squash/releases/download/$GITHUB_RELEASE_VERSION/initrd"
  wget -O "$DIR_PREFIX/vmlinuz" "https://github.com/netbootxyz/ubuntu-squash/releases/download/$GITHUB_RELEASE_VERSION/vmlinuz"
}

_download_ubuntu_squash 20.10-424a54b4
_download_ubuntu_squash 20.04.1-8de3099a

cd ..
